package com.diagbot.facade;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.diagbot.client.AuthServiceClient;
import com.diagbot.client.QcServiceClient;
import com.diagbot.dto.AlgorithmDTO;
import com.diagbot.dto.AnalyzeDTO;
import com.diagbot.dto.BehosDTO;
import com.diagbot.dto.BehospitalInfoDTO;
import com.diagbot.dto.MsgDTO;
import com.diagbot.dto.OutputInfo;
import com.diagbot.dto.QcCasesEntryDTO;
import com.diagbot.dto.QcModeDTO;
import com.diagbot.dto.QcResultDTO;
import com.diagbot.dto.RecordContentDTO;
import com.diagbot.dto.Response;
import com.diagbot.entity.BehospitalInfo;
import com.diagbot.entity.DoctorAdvice;
import com.diagbot.entity.HomeDiagnoseInfo;
import com.diagbot.entity.HomeOperationInfo;
import com.diagbot.entity.HomePage;
import com.diagbot.entity.QcCasesEntryPagedata;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.exception.CommonErrorCode;
import com.diagbot.exception.CommonException;
import com.diagbot.service.impl.BehospitalInfoServiceImpl;
import com.diagbot.util.BeanUtil;
import com.diagbot.util.DateUtil;
import com.diagbot.util.EncrypDES;
import com.diagbot.util.EntityUtil;
import com.diagbot.util.ListUtil;
import com.diagbot.util.MapUtil;
import com.diagbot.util.SysUserUtils;
import com.diagbot.vo.AlgorithmVO;
import com.diagbot.vo.AnalyzeVO;
import com.diagbot.vo.BehospitalPageVO;
import com.diagbot.vo.GetDetailVO;
import com.diagbot.vo.MedrecVo;
import com.diagbot.vo.QcResultAlgQueryVO;
import com.diagbot.vo.QcResultAlgVO;
import com.diagbot.vo.QueryVo;
import com.diagbot.vo.RecordContentVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

/**
 * @Description:
 * @author: zhoutg
 * @time: 2020/4/12 11:39
 */
@Component
public class BehospitalInfoFacade extends BehospitalInfoServiceImpl {

    @Autowired
    QcServiceClient qcServiceClient;
    @Autowired
    DoctorAdviceFacade doctorAdviceFacade;
    @Autowired
    HomePageFacade homePageFacade;
    @Autowired
    private QcCasesEntryFacade qcCasesEntryFacade;
    @Autowired
    HomeDiagnoseInfoFacade homeDiagnoseInfoFacade;
    @Autowired
    HomeOperationInfoFacade homeOperationInfoFacade;
    @Autowired
    MedicalRecordFacade medicalRecordFacade;
    @Autowired
    BasHospitalInfoFacade basHospitalInfoFacade;
    @Autowired
    private AlgorithmFacade algorithmFacade;
    @Autowired
    SysDictionaryFacade sysDictionaryFacade;
    @Autowired
    private QcresultInfoFacade qcresultInfoFacade;
    @Autowired
    QcModeFacade qcModeFacade;
    @Autowired
    AuthServiceClient authServiceClient;
    @Autowired
    QcCasesEntryPagedataFacade qcCasesEntryPagedataFacade;
    @Value("${encrypt.enable}")
    Boolean encryptFlag;

    public IPage<BehospitalInfoDTO> pageFac(BehospitalPageVO behospitalPageVO) {
        //入参验证
        //入院时间
        if (null != behospitalPageVO && null != behospitalPageVO.getBehosDateStart()) {
            behospitalPageVO.setBehosDateStart(DateUtil.getFirstTimeOfDay(behospitalPageVO.getBehosDateStart()));
        }
        if (null != behospitalPageVO && null != behospitalPageVO.getBehosDateEnd()) {
            behospitalPageVO.setBehosDateEnd(DateUtil.getLastTimeOfDay(behospitalPageVO.getBehosDateEnd()));
        }
        if (null != behospitalPageVO && null != behospitalPageVO.getBehosDateStart() && null != behospitalPageVO.getBehosDateEnd()) {
            if (DateUtil.after(behospitalPageVO.getBehosDateStart(), behospitalPageVO.getBehosDateEnd())) {
                throw new CommonException(CommonErrorCode.PARAM_IS_ERROR, "入院时间的开始时间必须小于结束时间！");
            }
        }
        //出院时间
        if (null != behospitalPageVO && null != behospitalPageVO.getLeaveHosDateStart()) {
            behospitalPageVO.setLeaveHosDateStart(DateUtil.getFirstTimeOfDay(behospitalPageVO.getLeaveHosDateStart()));
        }
        if (null != behospitalPageVO && null != behospitalPageVO.getLeaveHosDateEnd()) {
            behospitalPageVO.setLeaveHosDateEnd(DateUtil.getLastTimeOfDay(behospitalPageVO.getLeaveHosDateEnd()));
        }
        if (null != behospitalPageVO && null != behospitalPageVO.getLeaveHosDateStart() && null != behospitalPageVO.getLeaveHosDateEnd()) {
            if (DateUtil.after(behospitalPageVO.getLeaveHosDateStart(), behospitalPageVO.getLeaveHosDateEnd())) {
                throw new CommonException(CommonErrorCode.PARAM_IS_ERROR, "出院时间的开始时间必须小于结束时间！");
            }
        }
        behospitalPageVO.setHospitalId(Long.parseLong(SysUserUtils.getCurrentHospitalID()));
        IPage<BehospitalInfoDTO> res = getPage(behospitalPageVO);
        return res;
    }

    public Map<String, Object> getByBehospitalCode(GetDetailVO getDetailVO) {
        Map<String, Object> res = new HashMap<>(); // 返回结果
        Long hospitalId = Long.parseLong(SysUserUtils.getCurrentHospitalID());
        getDetailVO.setHospitalId(hospitalId);
        // 获取病历信息
        BehospitalInfo behospitalInfo = this.getOne(new QueryWrapper<BehospitalInfo>()
                .eq("is_deleted", IsDeleteEnum.N.getKey())
                .eq("hospital_id", getDetailVO.getHospitalId())
                .eq("behospital_code", getDetailVO.getBehospitalCode()), false
        );

        List<String> paramList = getDetailVO.getParamStr();// 参数列表

        if (ListUtil.isEmpty(paramList) || paramList.contains("beHospital")) {
            BehosDTO behosDTO = new BehosDTO();
            if (behospitalInfo == null) {
                throw new CommonException(CommonErrorCode.SERVER_IS_ERROR, "该病历已删除!");
            }
            BeanUtil.copyProperties(behospitalInfo, behosDTO);
            res.put("beHospital", behosDTO);
        }

        if (ListUtil.isEmpty(paramList) || paramList.contains("result") || paramList.contains("resultSimple")) {
            // 获取结果主表信息
            QcResultDTO qcResultDTO = qcresultInfoFacade.getByBehospitalCode(getDetailVO);
            if (qcResultDTO == null) {
                throw new CommonException(CommonErrorCode.SERVER_IS_ERROR, "该病历未评分!");
            }
            if (paramList.contains("resultSimple")) {
                qcResultDTO.setPageData("");
                qcResultDTO.setMenuData("");
            }
            res.put("result", qcResultDTO);
        }

        // 获取提示信息
        if (ListUtil.isEmpty(paramList) || paramList.contains("msg")) {
            AnalyzeVO analyzeVO = new AnalyzeVO();
            BeanUtil.copyProperties(getDetailVO, analyzeVO);
            List<MsgDTO> msgDTOList = getMsg(analyzeVO);
            List<Long> caseEntryId = msgDTOList.stream().map(r -> r.getCasesEntryId()).collect(Collectors.toList());
            if (ListUtil.isNotEmpty(caseEntryId)) {
                List<QcCasesEntryPagedata> qcCasesEntryPagedataList = qcCasesEntryPagedataFacade.list(new QueryWrapper<QcCasesEntryPagedata>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("hospital_id", hospitalId)
                        .in("cases_entry_id", caseEntryId)
                );
                Map<Long, List<QcCasesEntryPagedata>> pageKey = EntityUtil.makeEntityListMap(qcCasesEntryPagedataList, "casesEntryId");
                for (MsgDTO msgDTO : msgDTOList) {
                    List<QcCasesEntryPagedata> pagedata = pageKey.get(msgDTO.getCasesEntryId());
                    if (ListUtil.isNotEmpty(pagedata)) {
                        msgDTO.setPageKeyList(pagedata.stream().map(r -> r.getPageKey()).collect(Collectors.toList()));
                    }
                }
            }

            Map<String, List<MsgDTO>> msgMap = EntityUtil.makeEntityListMap(msgDTOList, "modelName");
            res.put("msg", msgMap);
        }
        return res;
    }

    public AnalyzeDTO analyze(AnalyzeVO analyzeVO) {
        Long hospitalId = analyzeVO.getHospitalId();
        if (!analyzeVO.getIsTask()) {
            hospitalId = Long.parseLong(SysUserUtils.getCurrentHospitalID());
        }
//        Long hospitalId = 1L; // 写死
        analyzeVO.setHospitalId(hospitalId);
        // 获取质控条目
        List<QcCasesEntryDTO> qcCasesEntryDTOList = qcCasesEntryFacade.getQcCasesEntry(analyzeVO);
        if(ListUtil.isEmpty(qcCasesEntryDTOList)){
            throw new CommonException(CommonErrorCode.NOT_EXISTS, "该病历找不到质控条目!");
        }

        // 获取病历所有数据
        Map<String, Map<String, String>> dicMap = sysDictionaryFacade.getDictionaryWithKey(); // 获取字典信息
        // 获取文书信息
        RecordContentVO recordContentVO = new RecordContentVO();
        BeanUtil.copyProperties(analyzeVO, recordContentVO);
        List<RecordContentDTO> recordContentDTOList = medicalRecordFacade.getRecordContentFac(recordContentVO);
        String recTitle = "";
        // 解密数据
        if (encryptFlag) {
            try {
                EncrypDES encrypDES = new EncrypDES();
                for (RecordContentDTO recordContentDTO : recordContentDTOList) {
                    recTitle = recordContentDTO.getRecTitle();
                    recordContentDTO.setContentText(encrypDES.decryptor(recordContentDTO.getContentText()));
                }
            } catch (Exception e) {
                throw new CommonException(CommonErrorCode.SERVER_IS_ERROR,
                        "解密错误!病历号=【" + analyzeVO.getBehospitalCode() + "】，医院文书名称=【" + recTitle + "】");
            }
        }

        Map<String, List<RecordContentDTO>> recMap = EntityUtil.makeEntityListMap(recordContentDTOList, "standModelName");

        // 获取医嘱
        List<DoctorAdvice> doctorAdviceList = doctorAdviceFacade.list(new QueryWrapper<DoctorAdvice>()
                .eq("is_deleted", IsDeleteEnum.N.getKey())
                .eq("hospital_id", hospitalId)
                .eq("behospital_code", analyzeVO.getBehospitalCode())
        );

        // 获取病案首页
        HomePage homePage = homePageFacade.getOne(new QueryWrapper<HomePage>()
                .eq("is_deleted", IsDeleteEnum.N.getKey())
                .eq("hospital_id", hospitalId)
                .eq("behospital_code", analyzeVO.getBehospitalCode()), false
        );

        List<HomeDiagnoseInfo> homePageList = new ArrayList<>();
        List<HomeOperationInfo> homeOperationInfoList = new ArrayList<>();
        if (homePage != null) {
            // 获取首页出院诊断、病理诊断
            homePageList = homeDiagnoseInfoFacade.list(new QueryWrapper<HomeDiagnoseInfo>()
                    .eq("is_deleted", IsDeleteEnum.N.getKey())
                    .eq("hospital_id", hospitalId)
                    .eq("home_page_id", homePage.getHomePageId())
            );

            // 获取首页手术信息
             homeOperationInfoList = homeOperationInfoFacade.list(new QueryWrapper<HomeOperationInfo>()
                    .eq("is_deleted", IsDeleteEnum.N.getKey())
                    .eq("hospital_id", hospitalId)
                    .eq("home_page_id", homePage.getHomePageId())
            );
        }

        // 拼接数据
        String hosCode = basHospitalInfoFacade.getHosCode(hospitalId);
        QueryVo queryVo = new QueryVo();
        queryVo.setCid(hosCode); // 设置医院编码
        queryVo.setInputCatalogueMap(getInputCatalogueMap(qcCasesEntryDTOList)); // 设置质控条目编码
        List<MedrecVo> medrecVoList = new ArrayList<>(); // 设置内容

        addData("入院记录", recMap, medrecVoList);
        addData("病危通知书", recMap, medrecVoList);
        addData("阶段小结", recMap, medrecVoList);
        addData("抢救记录", recMap, medrecVoList);
        addData("查房记录", recMap, medrecVoList);
        addData("首次病程录", recMap, medrecVoList);
        addData("输血/血制品病程记录", recMap, medrecVoList);
        addData("输血后效果评价", recMap, medrecVoList);
        addData("死亡病例讨论记录", recMap, medrecVoList);
        addData("死亡记录", recMap, medrecVoList);
        addData("危急值记录", recMap, medrecVoList);
        addData("出院小结", recMap, medrecVoList);
        addData("疑难病例讨论记录", recMap, medrecVoList);
        addData("输血后效果评价", recMap, medrecVoList);
        addData("病理检验送检单", recMap, medrecVoList);

        addDataWithInnerKey("知情同意书", recMap, medrecVoList);
        addDataWithInnerKey("谈话告知书", recMap, medrecVoList);

        // 会诊记录
        addDataWithKey("会诊", recMap, medrecVoList,
                Arrays.asList("会诊记录", "会诊结果单", "会诊申请单"));

        // 手术
        addDataWithKey("手术", recMap, medrecVoList,
                Arrays.asList("术后首次病程及谈话记录", "手术记录",
                        "术前讨论、术前小结", "手术知情同意书", "手术安全核查表"));

        // 医嘱
        if (ListUtil.isNotEmpty(doctorAdviceList)) {
            addDataWithKeyConvert("医嘱信息", doctorAdviceList, medrecVoList,
                    dicMap.get("1"), Arrays.asList("daStartDate", "daStopDate"));
        }

        // 病案首页
        if (homePage != null) {
            addDataWithFirstPage("病案首页", homePage, medrecVoList, dicMap,
                    homePageList, homeOperationInfoList);
        }

        queryVo.setMedrec(medrecVoList);

        //  调用质控接口
        Response<OutputInfo> response = qcServiceClient.extract(queryVo);
        if (response == null || response.getData() == null) {
            throw new CommonException(CommonErrorCode.RPC_ERROR, "远程质控接口没有返回数据!");
        }
        OutputInfo outputInfo = response.getData();
        //根据质控结果获取质控条目
        QcResultAlgQueryVO qcResultAlgQueryVO = new QcResultAlgQueryVO();
        List<String> codeList = new ArrayList<>();
        for (Map.Entry<String, Map<String, String>> output : outputInfo.getResult().entrySet()) {
            codeList.add(output.getKey());
        }
        qcResultAlgQueryVO.setCodeList(codeList);
        qcResultAlgQueryVO.setHospitalId(hospitalId);
        List<QcResultAlgVO> qcResultAlgVOList = qcCasesEntryFacade.getQcResultAlgVO(qcResultAlgQueryVO);
        // 评分
        AlgorithmVO algorithmVO = new AlgorithmVO();
        algorithmVO.setType(0);
        algorithmVO.setQcResultAlgVOList(qcResultAlgVOList);
        AlgorithmDTO algorithmDTO = algorithmFacade.getAlgorithmRes(algorithmVO);
        //保存
        Map<String, Object> pageMap = outputInfo.getPageData();
        String pageData = JSON.toJSONString(pageMap);
        // 获取菜单信息
        List<QcModeDTO> qcModeDTOList = qcModeFacade.getMenu(pageMap);
        String menuData = JSON.toJSONString(qcModeDTOList);

        Date date = qcresultInfoFacade.saveQcResult(algorithmDTO, algorithmVO, analyzeVO, pageData, menuData, analyzeVO.getIsTask());

        // 返回提示信息
        List<MsgDTO> msgDTOList = getMsg(analyzeVO);
        Map<String, List<MsgDTO>> msgMap = EntityUtil.makeEntityListMap(msgDTOList, "modelName");


        //返回参数组装
        AnalyzeDTO analyzeDTO = new AnalyzeDTO();
        analyzeDTO.setBehospitalCode(analyzeVO.getBehospitalCode());
        analyzeDTO.setIsSuccess(true);
        analyzeDTO.setGradeType(1);
        analyzeDTO.setGradeTypeName("机器");
        analyzeDTO.setScoreRes(algorithmDTO.getScore());
        analyzeDTO.setLevel(algorithmDTO.getLevel());
        analyzeDTO.setGradeTime(date);
        return analyzeDTO;
    }


    /**
     * 拼接数据
     *
     * @param key
     * @param recMap
     * @param medrecVoList
     */
    public void addData(String key, Map<String, List<RecordContentDTO>> recMap, List<MedrecVo> medrecVoList) {
        List<RecordContentDTO> list = recMap.get(key);
        Map<String, List<String>> listMap = new HashMap<>();
        if (ListUtil.isNotEmpty(list)) {
            MedrecVo medrecVo = new MedrecVo();
            medrecVo.setTitle(key);
            Map<String, Object> content = new HashMap<>();
            content.put("content", list.stream().map(r -> r.getContentText()).collect(Collectors.toList()));
            medrecVo.setContent(content);
            medrecVoList.add(medrecVo);
        }
    }


    /**
     * 拼接数据（例如：手术）
     *
     * @param key
     * @param recMap
     * @param medrecVoList
     */
    public void addDataWithKey(String key, Map<String, List<RecordContentDTO>> recMap,
                               List<MedrecVo> medrecVoList, List<String> keyList) {
        MedrecVo medrecVo = new MedrecVo();
        medrecVo.setTitle(key);
        Map<String, Object> content = new HashMap<>();
        Map<String, List<String>> listMap = new HashMap<>();
        Boolean flag = false;
        for (String k : keyList) {
            if (ListUtil.isNotEmpty(recMap.get(k))) {
                listMap.put(k, recMap.get(k).stream().map(r -> r.getContentText()).collect(Collectors.toList()));
                flag = true;
            }
        }
        if (flag) {
            // 会诊记录特殊处理，有会诊申请单，没有会诊结果单，复制一份到会诊结果单
            if ("会诊记录".equals(key) && ListUtil.isNotEmpty(listMap.get("会诊申请单"))
                    && ListUtil.isEmpty(listMap.get("会诊结果单"))) {
                listMap.put("会诊结果单", listMap.get("会诊申请单"));
            }
            content.put("content", listMap);
            medrecVo.setContent(content);
            medrecVoList.add(medrecVo);
        }
    }


    /**
     * 拼接数据（例如：知情同意书、谈话告知书）
     *
     * @param key
     * @param recMap
     * @param medrecVoList
     */
    public void addDataWithInnerKey(String key, Map<String, List<RecordContentDTO>> recMap, List<MedrecVo> medrecVoList) {
        MedrecVo medrecVo = new MedrecVo();
        medrecVo.setTitle(key);
        Map<String, Object> content = new HashMap<>();
        Map<String, List<String>> listMap = new HashMap<>();
        List<RecordContentDTO> recordContentDTOList = recMap.get(key);
        if (ListUtil.isNotEmpty(recordContentDTOList)) {
            Map<String, List<RecordContentDTO>> keyMap =
                    EntityUtil.makeEntityListMap(recordContentDTOList, "recTitle");
            Set<String> keyList = keyMap.keySet();
            for (String k : keyList) {
                if (ListUtil.isNotEmpty(keyMap.get(k))) {
                    listMap.put(k, keyMap.get(k).stream().map(r -> r.getContentText()).collect(Collectors.toList()));
                }
            }
            content.put("content", listMap);
            medrecVo.setContent(content);
            medrecVoList.add(medrecVo);
        }
    }

    /**
     * 拼接数据（医嘱),从数据字典获取信息转换
     *
     * @param key
     * @param list
     * @param medrecVoList
     * @param map
     */
    public void addDataWithKeyConvert(String key,  List<DoctorAdvice> list,
                               List<MedrecVo> medrecVoList, Map<String, String> map, List<String> dateList) {
        MedrecVo medrecVo = new MedrecVo();
        medrecVo.setTitle(key);
        Map<String, Object> content = new HashMap<>();
        List<String> contents = new ArrayList<>();

        for (DoctorAdvice doctorAdvice : list) {
            try {
                Map<String, String> res = new HashMap<>();
                Map<String, Object> objectMap = MapUtil.objectToMap(doctorAdvice);
                for (String objKey : objectMap.keySet()) {
                    if (map.get(objKey) != null) {
                        if (dateList.contains(objKey)) {
                            Date date = (Date)objectMap.get(objKey);
                            res.put(map.get(objKey), DateUtil.formatDateTime(date).replaceAll("null", ""));
                        } else {
                            res.put(map.get(objKey), String.valueOf(objectMap.get(objKey)).replaceAll("null", ""));
                        }
                    }
                }
                String jsonStr = JSON.toJSONString(res);
                contents.add(jsonStr);
            } catch (Exception e) {
                e.printStackTrace();
            }
        }

        content.put("content", contents);
        medrecVo.setContent(content);
        medrecVoList.add(medrecVo);
    }


    /**
     * 对象key转换
     *
     * @param dateList
     * @param dicMap
     * @param objectMap
     * @return
     */
    public Map<String, Object> objcetKeyConvert(List<String> dateList, Map<String, String> dicMap, Map<String, Object> objectMap) {
        Map<String, Object> res = new HashMap<>();
        for (String objKey : objectMap.keySet()) {
            if (dicMap.containsKey(objKey)) {
                if (dateList.contains(objKey)) {
                    Date date = (Date)objectMap.get(objKey);
                    res.put(dicMap.get(objKey), DateUtil.formatDateTime(date).replaceAll("null", ""));
                } else {
                    res.put(dicMap.get(objKey), String.valueOf(objectMap.get(objKey)).replaceAll("null", ""));
                }
            }
        }
        return res;
    }

    /**
     * 拼接数据（病案首页),从数据字典获取信息转换
     * @param key
     * @param homePage
     * @param medrecVoList
     * @param dicMap
     * @param homeDiagnoseInfoList
     * @param homeOperationInfoList
     */
    public void addDataWithFirstPage(String key,  HomePage homePage, List<MedrecVo> medrecVoList, Map<String, Map<String, String>> dicMap,
                                     List<HomeDiagnoseInfo> homeDiagnoseInfoList, List<HomeOperationInfo> homeOperationInfoList) {
        MedrecVo medrecVo = new MedrecVo();
        medrecVo.setTitle(key);

        Map<String, String> map = dicMap.get("2"); // 病案首页
        Map<String, Object> content = new HashMap<>();
        try {
            Map<String, Object> objectMap = MapUtil.objectToMap(homePage);
            List<String> firstPageDate = Arrays.asList("birthday", "behospitalDate", "leaveHospitalDate", "qcDate");
            for (String objKey : objectMap.keySet()) {
                if (map.containsKey(objKey)) {
                    if (firstPageDate.contains(objKey)) {
                        Date date = (Date)objectMap.get(objKey);
                        content.put(map.get(objKey), DateUtil.formatDateTime(date).replaceAll("null", ""));
                    } else {
                        content.put(map.get(objKey), String.valueOf(objectMap.get(objKey)).replaceAll("null", ""));
                    }
                }
            }

            // 病案首页手术信息
            if (ListUtil.isNotEmpty(homeOperationInfoList)) {
                Map<String, String> dic3 = dicMap.get("3"); // 病案首页手术信息
                List<Map> mapList = new ArrayList<>();
                List<String> operatDate = Arrays.asList("operationDate");
                for (HomeOperationInfo homeOperationInfo : homeOperationInfoList) {
                    try {
                        Map operatMap = objcetKeyConvert(operatDate, dic3, MapUtil.objectToMap(homeOperationInfo));
                        mapList.add(operatMap);
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                }
                content.put("手术信息", JSON.toJSONString(mapList));
            }

            // 病案首页诊断信息
            if (ListUtil.isNotEmpty(homeDiagnoseInfoList)) {
                Map<String, String> dic4 = dicMap.get("4"); // 病案首页诊断信息
                List<Map> mapList = new ArrayList<>();
                List<String> diagnoseDate = Arrays.asList("");
                for (HomeDiagnoseInfo homeDiagnoseInfo : homeDiagnoseInfoList) {
                    try {
                        Map objectMapDiag = objcetKeyConvert(diagnoseDate, dic4, MapUtil.objectToMap(homeDiagnoseInfo));
                        mapList.add(objectMapDiag);
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                }
                content.put("出院诊断", JSON.toJSONString(mapList));
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        medrecVo.setContent(content);
        medrecVoList.add(medrecVo);
    }


    /**
     * 获取质控条目编码
     *
     * @param qcCasesEntryDTOList
     * @return
     */
    public Map<String, Map<String, String>> getInputCatalogueMap(List<QcCasesEntryDTO> qcCasesEntryDTOList) {
        Map<String, Map<String, String>> res = new HashMap<>();
        for (QcCasesEntryDTO qc : qcCasesEntryDTOList) {
            Map<String, String> map = new HashMap<>();
            map.put("code", qc.getCode());
            map.put("precond", null);
            map.put("name", qc.getMsg());
            res.put(qc.getCode(), map);
        }
        return res;
    }


    /**
     * 执行未评分的病历
     */
    public void execute() {
        List<BehospitalInfo> behospitalInfoList = getNoGrade();
        for (BehospitalInfo bean : behospitalInfoList) {
            AnalyzeVO analyzeVO = new AnalyzeVO();
            analyzeVO.setIsTask(true);
            analyzeVO.setHospitalId(bean.getHospitalId());
            analyzeVO.setBehospitalCode(bean.getBehospitalCode());
            authServiceClient.analyze_rpc(analyzeVO);
        }

//        List<BehospitalInfo> behospitalInfoList = this.list(new QueryWrapper<BehospitalInfo>()
//                .eq("is_deleted", IsDeleteEnum.N.getKey())
//        );
//
//        int i = 1;
//        while(i < 100) {
//            for (BehospitalInfo bean : behospitalInfoList) {
//                AnalyzeVO analyzeVO = new AnalyzeVO();
//                analyzeVO.setIsTask(true);
//                analyzeVO.setHospitalId(bean.getHospitalId());
//                analyzeVO.setBehospitalCode(bean.getBehospitalCode());
//                authServiceClient.analyze_rpc(analyzeVO);
//                System.out.println(i++);
//            }
//        }
    }
}
