package com.diagbot.facade;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.diagbot.dto.AlgorithmDTO;
import com.diagbot.dto.AnalyzeDTO;
import com.diagbot.dto.QcResultDTO;
import com.diagbot.entity.BehospitalInfo;
import com.diagbot.entity.QcresultDetail;
import com.diagbot.entity.QcresultInfo;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.exception.CommonErrorCode;
import com.diagbot.exception.CommonException;
import com.diagbot.service.impl.QcresultDetailServiceImpl;
import com.diagbot.service.impl.QcresultInfoServiceImpl;
import com.diagbot.util.BeanUtil;
import com.diagbot.util.DateUtil;
import com.diagbot.util.ListUtil;
import com.diagbot.util.StringUtil;
import com.diagbot.util.SysUserUtils;
import com.diagbot.vo.AlgorithmVO;
import com.diagbot.vo.AnalyzeVO;
import com.diagbot.vo.GetDetailVO;
import com.diagbot.vo.QcResultAlgVO;
import com.diagbot.vo.QcresultVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * @Description:
 * @Author:zhaops
 * @time: 2020/4/13 17:22
 */
@Component
public class QcresultInfoFacade extends QcresultInfoServiceImpl {
    @Autowired
    @Qualifier("qcresultDetailServiceImpl")
    private QcresultDetailServiceImpl qcresultDetailServiceImpl;
    @Autowired
    private AlgorithmFacade algorithmFacade;
    @Autowired
    private BehospitalInfoFacade behospitalInfoFacade;

    /**
     * 修改评分结果信息
     *
     * @param qcresultVO 修改评分结果信息
     * @return 评分的结果
     */
    public AnalyzeDTO changeQcResult(QcresultVO qcresultVO) {
        //入参验证
        if (StringUtil.isBlank(qcresultVO.getBehospitalCode())) {
            throw new CommonException(CommonErrorCode.PARAM_IS_NULL, "病历id不能为空！");
        }
        if (null == qcresultVO.getOptResultAlgVO()) {
            throw new CommonException(CommonErrorCode.PARAM_IS_NULL, "操作条目不能为空！");
        }

        Long hospitalId = Long.valueOf(SysUserUtils.getCurrentHospitalID());
        //验证病历的存在性
        Integer mrcnt
                = behospitalInfoFacade.count(
                new QueryWrapper<BehospitalInfo>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("hospital_id", hospitalId)
                        .eq("behospital_code", qcresultVO.getBehospitalCode()));
        if (mrcnt < 1) {
            throw new CommonException(CommonErrorCode.NOT_EXISTS, "该医院下该病历号不存在！");
        }
        //验证是否评估过
        Integer cnt
                = this.count(
                new QueryWrapper<QcresultInfo>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("hospital_id", hospitalId)
                        .eq("behospital_code", qcresultVO.getBehospitalCode()));
        if (cnt < 1) {
            throw new CommonException(CommonErrorCode.NOT_EXISTS, "该病历尚未评分，请先评分！");
        }
        //查询质控评分明细信息
        qcresultVO.setHospitalId(hospitalId);
        List<QcresultDetail> qcresultDetails
                = qcresultDetailServiceImpl.list(
                new QueryWrapper<QcresultDetail>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("hospital_id", hospitalId)
                        .eq("behospital_code", qcresultVO.getBehospitalCode()));

        //评分
        AlgorithmVO algorithmVO = new AlgorithmVO();
        List<QcResultAlgVO> qcResultAlgVOList
                = BeanUtil.listCopyTo(qcresultDetails, QcResultAlgVO.class);
        algorithmVO.setType(qcresultVO.getType());
        algorithmVO.setOptResultAlgVO(qcresultVO.getOptResultAlgVO());
        algorithmVO.setQcResultAlgVOList(qcResultAlgVOList);
        AlgorithmDTO algorithmDTO = algorithmFacade.getAlgorithmRes(algorithmVO);
        //更新质控评分结果信息
        AnalyzeVO analyzeVO = new AnalyzeVO();
        analyzeVO.setHospitalId(hospitalId);
        analyzeVO.setBehospitalCode(qcresultVO.getBehospitalCode());
        Date date = this.saveQcResult(algorithmDTO, algorithmVO, analyzeVO, null, null, false);
        //返回参数组装
        AnalyzeDTO analyzeDTO = new AnalyzeDTO();
        analyzeDTO.setBehospitalCode(qcresultVO.getBehospitalCode());
        analyzeDTO.setIsSuccess(true);
        analyzeDTO.setGradeType(2);
        analyzeDTO.setGradeTypeName("人工");
        analyzeDTO.setScoreRes(algorithmDTO.getScore());
        analyzeDTO.setLevel(algorithmDTO.getLevel());
        analyzeDTO.setGradeTime(date);
        return analyzeDTO;
    }

    /**
     * 保存评分结果信息
     *
     * @param algorithmDTO 评分结果
     * @param algorithmVO  操作的条目
     * @param analyzeVO    病历信息
     * @param pageData     大数据解析出来的页面信息
     * @param menuData     菜单信息
     * @param isTask       是否是任务
     * @return 评分的时间
     */
    public Date saveQcResult(AlgorithmDTO algorithmDTO, AlgorithmVO algorithmVO, AnalyzeVO analyzeVO,
                             String pageData, String menuData, Boolean isTask) {
        //更新质控评分结果信息
        Long useId = 0L;
        if (!isTask) {
            useId = Long.valueOf(SysUserUtils.getCurrentPrincipleID());
        }
        Date now = DateUtil.now();
        //获取旧记录
        QcresultInfo qcresultInfo
                = this.getOne(
                new QueryWrapper<QcresultInfo>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("hospital_id", analyzeVO.getHospitalId())
                        .eq("behospital_code", analyzeVO.getBehospitalCode()));
        if (null == qcresultInfo) {
            qcresultInfo = new QcresultInfo();
        } else {
            //逻辑删除记录
            this.update(new UpdateWrapper<QcresultInfo>()
                    .eq("is_deleted", IsDeleteEnum.N.getKey())
                    .eq("hospital_id", analyzeVO.getHospitalId())
                    .eq("behospital_code", analyzeVO.getBehospitalCode())
                    .set("is_deleted", IsDeleteEnum.Y.getKey())
                    .set("modifier", useId)
                    .set("gmt_modified", now));
        }
        //新增记录
        qcresultInfo.setBehospitalCode(analyzeVO.getBehospitalCode());
        qcresultInfo.setHospitalId(analyzeVO.getHospitalId());
        qcresultInfo.setScoreRes(algorithmDTO.getScore());
        qcresultInfo.setLevel(algorithmDTO.getLevel());
        if (algorithmVO.getType().equals(0)) {
            qcresultInfo.setGradeType(1);
        } else {
            qcresultInfo.setGradeType(2);
        }
        if (StringUtil.isNotBlank(pageData)) {
            qcresultInfo.setPageData(pageData);
        }
        if (StringUtil.isNotBlank(menuData)) {
            qcresultInfo.setMenuData(menuData);
        }

        qcresultInfo.setGmtCreate(now);
        qcresultInfo.setCreator(useId.toString());
        qcresultInfo.setGmtModified(now);
        qcresultInfo.setModifier(useId.toString());
        this.save(qcresultInfo);
        //更新质控评分明细信息
        //逻辑删除记录
        qcresultDetailServiceImpl.update(new UpdateWrapper<QcresultDetail>()
                .eq("is_deleted", IsDeleteEnum.N.getKey())
                .eq("hospital_id", analyzeVO.getHospitalId())
                .eq("behospital_code", analyzeVO.getBehospitalCode())
                .set("is_deleted", IsDeleteEnum.Y.getKey())
                .set("modifier", useId)
                .set("gmt_modified", now));
        //批量插入新的数据
        List<QcresultDetail> qcresultDetailList = new ArrayList<>();
        List<QcResultAlgVO> qcResultAlgVORes = algorithmVO.getQcResultAlgVOList();
        if (ListUtil.isNotEmpty(qcResultAlgVORes)) {
            for (QcResultAlgVO qcResultAlgVO : qcResultAlgVORes) {
                QcresultDetail qcresultDetail = new QcresultDetail();
                BeanUtil.copyProperties(qcResultAlgVO, qcresultDetail);
                qcresultDetail.setHospitalId(analyzeVO.getHospitalId());
                qcresultDetail.setBehospitalCode(analyzeVO.getBehospitalCode());
                qcresultDetail.setGmtCreate(now);
                qcresultDetail.setCreator(useId.toString());
                qcresultDetail.setGmtModified(now);
                qcresultDetail.setModifier(useId.toString());
                qcresultDetailList.add(qcresultDetail);
            }
            qcresultDetailServiceImpl.saveBatch(qcresultDetailList);
        }
        return now;
    }


    /**
     * 获取评分主表信息
     *
     * @param getDetailVO
     * @return
     */
    public QcResultDTO getByBehospitalCode(GetDetailVO getDetailVO) {
        QcResultDTO res = new QcResultDTO();
        QcresultInfo qcresultInfo = this.getOne(new QueryWrapper<QcresultInfo>()
                .eq("is_deleted", IsDeleteEnum.N.getKey())
                .eq("hospital_id", getDetailVO.getHospitalId())
                .eq("behospital_code", getDetailVO.getBehospitalCode()), false
        );
        if (qcresultInfo != null) {
            BeanUtil.copyProperties(qcresultInfo, res);
        } else {
            return null;
        }
        return res;
    }
}
