package com.diagbot.web;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.diagbot.annotation.SysLogger;
import com.diagbot.dto.AnalyzeDTO;
import com.diagbot.dto.BehospitalInfoDTO;
import com.diagbot.dto.RespDTO;
import com.diagbot.facade.BehospitalInfoFacade;
import com.diagbot.facade.QcresultInfoFacade;
import com.diagbot.vo.AnalyzeVO;
import com.diagbot.vo.BehospitalPageVO;
import com.diagbot.vo.GetDetailVO;
import com.diagbot.vo.QcresultVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import springfox.documentation.annotations.ApiIgnore;

import java.util.Map;

/**
 * <p>
 * 住院病历信息 前端控制器
 * </p>
 *
 * @author zhoutg
 * @since 2020-04-13
 */
@RestController
@RequestMapping("/qc/behospitalInfo")
@Api(value = "病历API", tags = { "病历API" })
@SuppressWarnings("unchecked")
public class BehospitalInfoController {
    @Autowired
    BehospitalInfoFacade behospitalInfoFacade;
    @Autowired
    private QcresultInfoFacade qcresultInfoFacade;

    @ApiOperation(value = "病历分页列表[by:zhoutg]",
            notes = "name：姓名<br>" +
                    "fileCode：档案号<br>" +
                    "behosDateStart：入院时间开始时间<br>" +
                    "behosDateEnd：入院时间结束时间<br>" +
                    "leaveHosDateStart：出院时间开始时间<br>" +
                    "leaveHosDateEnd：出院时间结束时间<br>")
    @PostMapping("/page")
    @SysLogger("page")
    public RespDTO<IPage<BehospitalInfoDTO>> page(@RequestBody BehospitalPageVO behospitalPageVO) {
        IPage<BehospitalInfoDTO> data = behospitalInfoFacade.pageFac(behospitalPageVO);
        return RespDTO.onSuc(data);
    }

    @ApiOperation(value = "根据病历id获取详情[by:zhoutg]",
            notes = "")
    @PostMapping("/getByBehospitalCode")
    @SysLogger("getByBehospitalCode")
    public RespDTO<Map<String, Object>> getByBehospitalCode(@RequestBody GetDetailVO getDetailVO) {
        Map<String, Object> data = behospitalInfoFacade.getByBehospitalCode(getDetailVO);
        return RespDTO.onSuc(data);
    }


    @ApiOperation(value = "评分[by:zhoutg]",
            notes = "")
    @PostMapping("/analyze")
    @SysLogger("analyze")
    @Transactional
    public RespDTO<AnalyzeDTO> analyze(@RequestBody AnalyzeVO analyzeVO) {
        return RespDTO.onSuc(behospitalInfoFacade.analyze(analyzeVO));
    }

    @ApiOperation(value = "评分[by:zhoutg]",
            notes = "")
    @PostMapping("/analyze_rpc")
    @SysLogger("analyze_rpc")
    @Transactional
    @ApiIgnore
    public RespDTO<AnalyzeDTO> analyze_rpc(@RequestBody AnalyzeVO analyzeVO) {
        return RespDTO.onSuc(behospitalInfoFacade.analyze(analyzeVO));
    }

    @ApiOperation(value = "新增质控条目[by:zhoutg]",
            notes = "")
    @PostMapping("/addCase")
    @SysLogger("addCase")
    @Transactional
    public RespDTO<AnalyzeDTO> addCase(@RequestBody QcresultVO qcresultVO){
        qcresultVO.setType(1);
        return RespDTO.onSuc(qcresultInfoFacade.changeQcResult(qcresultVO));
    }

    @ApiOperation(value = "删除质控条目[by:zhoutg]",
            notes = "behospitalCode：病历号，必填<br>" +
                    "id：明细id，必填<br>")
    @PostMapping("/delCase")
    @SysLogger("delCase")
    @Transactional
    public RespDTO<AnalyzeDTO> delCase(@RequestBody QcresultVO qcresultVO){
        qcresultVO.setType(2);
        return RespDTO.onSuc(qcresultInfoFacade.changeQcResult(qcresultVO));
    }

    @ApiOperation(value = "修改质控条目[by:zhoutg]",
            notes = "")
    @PostMapping("/updCase")
    @SysLogger("updCase")
    @Transactional
    public RespDTO<AnalyzeDTO> updCase(@RequestBody QcresultVO qcresultVO){
        qcresultVO.setType(3);
        return RespDTO.onSuc(qcresultInfoFacade.changeQcResult(qcresultVO));
    }

    @ApiOperation(value = "批量执行[by:zhoutg]",
            notes = "")
    @PostMapping("/execule")
    @SysLogger("execule")
    public RespDTO<Boolean> execule(){
        behospitalInfoFacade.execute();
        return RespDTO.onSuc(true);
    }
}
