package com.diagbot.web;

import com.diagbot.annotation.SysLogger;
import com.diagbot.dto.JwtDTO;
import com.diagbot.dto.LoginDTO;
import com.diagbot.dto.ModifyPasswordVO;
import com.diagbot.dto.RespDTO;
import com.diagbot.entity.Token;
import com.diagbot.facade.TokenFacade;
import com.diagbot.facade.SysUserFacade;
import com.diagbot.vo.JwtVO;
import com.diagbot.vo.UserLoginVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.oauth2.common.OAuth2AccessToken;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import springfox.documentation.annotations.ApiIgnore;

/**
 * @Description: 用户账号API
 * @author: gaodm
 * @time: 2018/8/2 13:56
 */
@RestController
@Api(value = "用户账号API", tags = { "用户账号API" })
@RequestMapping("/sys/user")
@SuppressWarnings("unchecked")
public class SysUserController {

    @Autowired
    private SysUserFacade userFacade;
    @Autowired
    private TokenFacade tokenFacade;

    @ApiOperation(value = "验证token有效性[by:gaodm]",
            notes = "token：token信息，必填<br>")
    @PostMapping("/verifyToken")
    @SysLogger("verifyToken")
    @ApiIgnore
    public RespDTO<Boolean> verifyToken(@RequestBody Token token) {
        Boolean data = tokenFacade.verifyToken(token.getToken(), 1);
        return RespDTO.onSuc(data);
    }


    @ApiOperation(value = "登录获取jwt[by:gaodm]",
            notes = "username：用户名,必填<br>" +
                    "password：密码, 必填, 默认密码：dc483e80a7a0bd9ef71d8cf973673924<br> ")
    @PostMapping("/getJwt")
    @SysLogger("getJwt")
    public RespDTO<JwtDTO> getJwt(@RequestBody UserLoginVO userLoginVO) {
        JwtDTO data = userFacade.getJwt(userLoginVO.getUsername(), userLoginVO.getPassword());
        return RespDTO.onSuc(data);
    }

    @ApiOperation(value = "刷新jwt[by:gaodm]",
            notes = "refreshToken：刷新令牌,必填<br>")
    @PostMapping("/refreshJwt")
    @SysLogger("refreshJwt")
    public RespDTO<JwtDTO> refreshJwt(@RequestBody JwtVO jwtVO) {
        JwtDTO data = userFacade.refreshJwt(jwtVO.getToken());
        return RespDTO.onSuc(data);
    }

    @ApiOperation(value = "验证Token[by:gaodm]",
            notes = "checkToken：令牌,必填<br>")
    @PostMapping("/checkToken")
    @SysLogger("checkToken")
    public RespDTO<OAuth2AccessToken> checkToken(@RequestBody JwtVO jwtVO) {
        OAuth2AccessToken data = userFacade.checkToken(jwtVO.getToken());
        return RespDTO.onSuc(data);
    }

    @ApiOperation(value = "修改密码[by:gaodm]",
            notes = "password：原密码,必填<br>" +
                    "modifyPassword：新密码, 必填<br> ")
    @PostMapping("/midifyPassword")
    @SysLogger("midifyPassword")
    @Transactional
    public RespDTO<Boolean> midifyPassword(@RequestBody ModifyPasswordVO modifyPasswordVO) {
        Boolean flag = userFacade.modifyPassword(modifyPasswordVO.getPassword(), modifyPasswordVO.getModifyPassword());
        return RespDTO.onSuc(flag);
    }


    @ApiOperation(value = "获取用户、医院、菜单信息[by:gaodm]",
            notes = "")
    @PostMapping("/getUserOrgMenu")
    @SysLogger("getUserOrgMenu")
    public RespDTO<LoginDTO> getUserOrgMenu() {
        LoginDTO data = userFacade.getUserOrgMenu();
        return RespDTO.onSuc(data);
    }

}
